@@ -3,6 +3,8 @@
 # SPDX-FileCopyrightText: 2023 Fushan Wen <qydwhotmail@gmail.com>
 # SPDX-License-Identifier: MIT
 
+import subprocess
+import time
 import unittest
 from typing import Final
 
@@ -46,6 +48,13 @@ class KCMAutoStartTest(unittest.TestCase):
         """
         Make sure to terminate the driver again, lest it dangles.
         """
+        cls.driver.find_element(AppiumBy.XPATH, "//*[@name='Close' and contains(@accessibility-id, 'Button')]").click()
+        for _ in range(10):
+            try:
+                subprocess.check_call(["pidof", f"kcmshell{KDE_VERSION}"])
+            except subprocess.CalledProcessError:
+                break
+            time.sleep(1)
         cls.driver.quit()
 
     def test_0_open(self) -> None:
