@@ -39,7 +39,7 @@ private:
     // Only run one check at a time
     bool m_checking = false;
 
-    QString m_path;
+    const QString m_path;
     KLocalizedString m_notificationText;
 
     QTimer m_timer;
