@@ -31,11 +31,11 @@ static QString output2text(ClipCommand::Output output)
 {
     switch (output) {
     case ClipCommand::IGNORE:
-        return QString(i18n("Ignore"));
+        return i18n("Ignore");
     case ClipCommand::REPLACE:
-        return QString(i18n("Replace Clipboard"));
+        return i18n("Replace Clipboard");
     case ClipCommand::ADD:
-        return QString(i18n("Add to Clipboard"));
+        return i18n("Add to Clipboard");
     }
     return QString();
 }
@@ -62,7 +62,11 @@ public:
     void replaceCommand(const ClipCommand &command, const QModelIndex &idx);
 
 private:
-    enum column_t { COMMAND_COL = 0, OUTPUT_COL = 1, DESCRIPTION_COL = 2 };
+    enum column_t {
+        COMMAND_COL = 0,
+        OUTPUT_COL = 1,
+        DESCRIPTION_COL = 2,
+    };
     QList<ClipCommand> m_commands;
     QVariant displayData(ClipCommand *command, column_t column) const;
     QVariant decorationData(ClipCommand *command, column_t column) const;
@@ -402,3 +406,5 @@ void EditActionDialog::onSelectionChanged()
     m_removeCommandPb->setEnabled(itemIsSelected);
     m_editCommandPb->setEnabled(itemIsSelected);
 }
+
+#include "moc_editactiondialog.cpp"
