@@ -35,11 +35,6 @@ namespace KActivities
 class Controller;
 } // namespace KActivities
 
-namespace KDeclarative
-{
-class QmlObjectSharedEngine;
-} // namespace KDeclarative
-
 namespace KScreen
 {
 class Output;
@@ -91,6 +86,8 @@ public:
 
     Q_INVOKABLE QStringList availableActivities() const;
 
+    void clonePanelTo(PanelView *panel, Plasma::Types::Location location, QScreen *screen);
+
     PanelView *panelView(Plasma::Containment *containment) const;
     void savePreviousWindow();
     void restorePreviousWindow();
