@@ -4,7 +4,9 @@
     SPDX-License-Identifier: GPL-2.0-or-later
 */
 
-#include <QtTest>
+#include <QSignalSpy>
+#include <QStandardPaths>
+#include <QTest>
 
 #include "../slidefiltermodel.h"
 #include "../slidemodel.h"
@@ -30,6 +32,7 @@ private Q_SLOTS:
      * able to provide a correct updated list.
      * @see https://bugs.kde.org/show_bug.cgi?id=473088
      */
+    void testSlideFilterModelSortingRandomOrderWithFileAddedRemoved_data();
     void testSlideFilterModelSortingRandomOrderWithFileAddedRemoved();
     void testSlideFilterModelUncheckedSlides();
 
@@ -41,7 +44,10 @@ private:
     QString m_wallpaperPath;
     QString m_standardPath;
     QString m_pathA, m_pathB, m_pathC;
-    QSize m_targetSize;
+    QProperty<QSize> m_targetSize;
+    QProperty<bool> m_usedInConfig{false};
+    QProperty<SortingMode::Mode> m_sortingMode{SortingMode::Random};
+    QProperty<bool> m_sortingFoldersFirst{false};
 };
 
 void SlideFilterModelTest::initTestCase()
@@ -80,8 +86,11 @@ void SlideFilterModelTest::initTestCase()
 
 void SlideFilterModelTest::init()
 {
-    m_model = new SlideModel(m_targetSize, this);
-    m_filterModel = new SlideFilterModel(this);
+    m_model = new SlideModel(QBindable<QSize>(&m_targetSize), QBindable<bool>(&m_usedInConfig), this);
+    m_filterModel = new SlideFilterModel(QBindable<bool>(&m_usedInConfig), //
+                                         QBindable<SortingMode::Mode>(&m_sortingMode), //
+                                         QBindable<bool>(&m_sortingFoldersFirst), //
+                                         this);
 
     // Test loading data
     m_model->setSlidePaths({m_standardPath});
@@ -130,7 +139,8 @@ void SlideFilterModelTest::testSlideFilterModelSortingOrder()
     QFETCH(bool, folderFirst);
     QFETCH(QStringList, expected);
 
-    m_filterModel->setSortingMode(order, folderFirst);
+    m_sortingMode = order;
+    m_sortingFoldersFirst = folderFirst;
     QCOMPARE(m_filterModel->rowCount(), 3);
 
     for (int i = 0; i < expected.size(); i++) {
@@ -144,9 +154,10 @@ void SlideFilterModelTest::testSlideFilterModelSortingRandomOrder()
     QCOMPARE(m_filterModel->rowCount(), counts.size());
 
     // Monte Carlo
+    m_sortingMode = SortingMode::Random;
+    m_sortingFoldersFirst = false;
     for (int i = 0; i < 1000; i++) {
-        m_filterModel->setSortingMode(SortingMode::Random, false);
-
+        m_filterModel->invalidate();
         const QString firstElement = m_filterModel->index(0, 0).data(ImageRoles::PackageNameRole).toString();
 
         if (firstElement == m_pathA) {
@@ -164,18 +175,27 @@ void SlideFilterModelTest::testSlideFilterModelSortingRandomOrder()
     }
 }
 
+void SlideFilterModelTest::testSlideFilterModelSortingRandomOrderWithFileAddedRemoved_data()
+{
+    QTest::addColumn<bool>("usedInConfig");
+
+    QTest::newRow("usedInConfig: false") << false;
+    QTest::newRow("usedInConfig: true") << true;
+}
+
 void SlideFilterModelTest::testSlideFilterModelSortingRandomOrderWithFileAddedRemoved()
 {
-    m_filterModel->setProperty("usedInConfig", false);
+    QFETCH(bool, usedInConfig);
+    m_usedInConfig = usedInConfig;
 
-    m_filterModel->setSortingMode(SortingMode::Random, false);
+    m_sortingMode = SortingMode::Random;
+    m_sortingFoldersFirst = false;
     int oldRowCount = m_filterModel->rowCount();
 
     qDebug() << "Before adding a new wallpaper";
     QStringList oldPaths;
     for (int i = 0, count = m_filterModel->rowCount(); i < count; ++i) {
-        oldPaths.append(m_filterModel->index(i, 0).data(ImageRoles::PackageNameRole).toString());
-        qDebug() << i << *oldPaths.crbegin();
+        qDebug() << i << oldPaths.emplace_back(m_filterModel->index(i, 0).data(ImageRoles::PackageNameRole).toString());
     }
     qDebug() << "Before adding a new wallpaper";
 
@@ -195,11 +215,15 @@ void SlideFilterModelTest::testSlideFilterModelSortingRandomOrderWithFileAddedRe
     for (int i = 0, count = oldPaths.size(); i < count; ++i) {
         // Make sure the old order is not changed
         qDebug() << i << m_filterModel->index(i, 0).data(ImageRoles::PackageNameRole).toString();
-        QCOMPARE(oldPaths[i], m_filterModel->index(i, 0).data(ImageRoles::PackageNameRole).toString());
+        QCOMPARE(oldPaths[i], m_filterModel->index(i + (usedInConfig ? 1 : 0), 0).data(ImageRoles::PackageNameRole).toString());
     }
     qDebug() << "After adding a new wallpaper";
 
-    QCOMPARE(m_filterModel->index(m_filterModel->rowCount() - 1, 0).data(ImageRoles::PackageNameRole).toString(), newImagePath);
+    if (usedInConfig) {
+        QCOMPARE(m_filterModel->index(0, 0).data(ImageRoles::PackageNameRole).toString(), newImagePath);
+    } else {
+        QCOMPARE(m_filterModel->index(m_filterModel->rowCount() - 1, 0).data(ImageRoles::PackageNameRole).toString(), newImagePath);
+    }
 
     // Now remove the wallpaper
     oldRowCount = m_filterModel->rowCount();
@@ -224,12 +248,11 @@ void SlideFilterModelTest::testSlideFilterModelUncheckedSlides()
 {
     m_model->setUncheckedSlides({m_pathA});
 
-    // usedInConfig false
-    m_filterModel->setProperty("usedInConfig", false);
-    QCOMPARE(m_filterModel->rowCount(), 2);
-
-    m_filterModel->setProperty("usedInConfig", true);
+    m_usedInConfig = true;
     QCOMPARE(m_filterModel->rowCount(), 3);
+
+    m_usedInConfig = false;
+    QCOMPARE(m_filterModel->rowCount(), 2);
 }
 
 QTEST_MAIN(SlideFilterModelTest)
